Package: ciecl
Title: International Classification of Diseases 'ICD-10'/'ICD-11' for
        Chile
Version: 0.9.6
Authors@R: 
    person("Rodolfo", "Tasso Suazo",
           email = "rtasso@uchile.cl",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-1264-4933"))
Description: Tools for working with the International Classification of
    Diseases ('ICD-10' Chile official 'MINSAL'/'DEIS' v2018). Includes
    optimized 'SQL' search with 'SQLite', fuzzy matching of medical terms
    ('Jaro-Winkler'), Charlson and Elixhauser comorbidity calculation,
    'WHO' 'ICD-11' 'API' integration, and hierarchical code validation.
    Data from Centro FIC Chile 'DEIS' <https://deis.minsal.cl/centrofic/>.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
Depends: R (>= 4.1.0)
Imports: DBI, RSQLite, stringdist, stringr, dplyr, tibble, tools, utils
Suggests: comorbidity, gt, httr2, readxl, usethis, withr, writexl,
        testthat (>= 3.1.5), knitr, litedown (>= 0.9), rmarkdown
VignetteBuilder: knitr
URL: https://rodotasso.github.io/ciecl/,
        https://github.com/RodoTasso/ciecl
BugReports: https://github.com/RodoTasso/ciecl/issues
Config/testthat/edition: 3
Config/Needs/website: pkgdown
Language: en, es
NeedsCompilation: no
Packaged: 2026-04-19 00:45:44 UTC; tassu
Author: Rodolfo Tasso Suazo [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1264-4933>)
Maintainer: Rodolfo Tasso Suazo <rtasso@uchile.cl>
Repository: CRAN
Date/Publication: 2026-04-19 14:30:02 UTC
Built: R 4.6.0; ; 2026-04-29 00:40:19 UTC; unix
