# Generated by roxygen2: do not edit by hand

export(cie10_clear_cache)
export(cie10_disconnect)
export(cie10_sql)
export(cie11_search)
export(cie_comorbid)
export(cie_expand)
export(cie_guia_busqueda)
export(cie_lookup)
export(cie_map_comorbid)
export(cie_normalizar)
export(cie_search)
export(cie_siglas)
export(cie_table)
export(cie_validate_vector)
importFrom(DBI,dbConnect)
importFrom(DBI,dbDisconnect)
importFrom(DBI,dbExecute)
importFrom(DBI,dbExistsTable)
importFrom(DBI,dbGetQuery)
importFrom(DBI,dbIsValid)
importFrom(DBI,dbWriteTable)
importFrom(RSQLite,SQLite)
importFrom(dplyr,"%>%")
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,matches)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice_head)
importFrom(stringdist,stringsim)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_trim)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tibble,tribble)
importFrom(utils,data)
importFrom(utils,packageVersion)
