% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cie-table.R
\name{cie_table}
\alias{cie_table}
\title{Generar tabla HTML interactiva GT de codigo CIE-10}
\usage{
cie_table(codigo)
}
\arguments{
\item{codigo}{String codigo (ej. "E11" muestra jerarquia)}
}
\value{
Objeto de clase \code{gt_tbl} (tabla HTML interactiva)
}
\description{
Generar tabla HTML interactiva GT de codigo CIE-10
}
\examples{
# Requiere paquete gt
requireNamespace("gt", quietly = TRUE)

\donttest{
cie_table("E11")  # Diabetes tipo 2 completo
}
}
\seealso{
\code{\link{cie_search}}, \code{\link{cie_lookup}}
}
\concept{visualizacion}
